import { For, Show, createSignal, onMount } from "solid-js";
import { LoadingStatus, backend, useLoading, wait } from "../utils/functions";
import { JsonResult } from "../types/JsonResult";
import { ClassroomCourse } from "../types/ClassroomCourse";
import { LoadingIcon } from "../icons/LoadingIcon";

export function ClassroomUserCourses(props: {userid: number}) {
    const [courses, setCourses] = createSignal<Array<ClassroomCourse>>([]);
    const {setError, status, setStatus} = useLoading();

    const loadCourses = async() => {
        setStatus(LoadingStatus.Loading);
        setError("");

        if (import.meta.env.DEV) await wait(1500);

        backend.get<JsonResult<Array<ClassroomCourse>>>(`/api/classroom/course/${props.userid}`)
            .then((res) => {
                setCourses(res.data.Ok);

                setStatus(LoadingStatus.Ok);
            })
            .catch((err) => {
                console.log(err);
                setError(err);
                setStatus(LoadingStatus.Error);
            });
    };

    onMount(loadCourses);

    return (
        <div class="w-full">
            <h2 class="text-2xl">
                Cursos matriculados:
            </h2>

            <div class="py-2 text-center">
                <Show when={status() === LoadingStatus.Loading}>
                    <span class="inline-block scale-[200%]">
                        <LoadingIcon
                            class="animate-spin mr-2"
                            fill="var(--c-primary)"
                            size={16}
                        />
                    </span>
                </Show>
            </div>

            <For each={courses()}>
                {(c) => (<p>{c.name}</p>)}
            </For>
            <Show when={status() === LoadingStatus.Ok && courses().length === 0}>
                <p>Esta persona no está matriculada en ningún curso</p>
            </Show>
        </div>
    );
}
